| Title: | US Baby Names 1880-2017 |
|---|---|
| Description: | US baby names provided by the SSA. This package contains all names used for at least 5 children of either sex. |
| Authors: | Hadley Wickham [aut, cre], RStudio [cph] |
| Maintainer: | Hadley Wickham <[email protected]> |
| License: | CC0 |
| Version: | 1.0.1 |
| Built: | 2026-05-28 08:22:43 UTC |
| Source: | https://github.com/hadley/babynames |
The SSA baby names data comes from social security number (SSN) applications. SSA cards were first issued in 1936, but were only needed for people with an income. In 1986, the law changed effectively requiring all children to get an SSN at birth.
applicantsapplicants
A data frame with 3 variables: year, sex and
applicants
Full baby name data provided by the SSA. This includes all names with at least 5 uses.
babynamesbabynames
A data frame with five variables: year, sex,
name, n and prop (n divided by total number
of applicants in that year, which means proportions are of people of
that sex with that name born in that year).
Live births data from census.gov.
birthsbirths
A data frame:
Year
Number of live births, rounded to nearest 1000
Cohort life tables data as provided by SSA.
lifetableslifetables
A data frame with nine variables:
xage in years
qxprobability of death at age x
lxnumber of survivors, of birth cohort of 100,000, at next integral age
dxnumber of deaths that would occur between integral ages
LxNumber of person-years lived between x and x+1
TxTotal number of person-years lived beyond age x
exAverage number of years of life remaining for members of cohort alive at age x
sexSex
yearYear
For further details, see http://www.ssa.gov/oact/NOTES/as120/LifeTables_Body.html#wp1168594